@@ -1,3 +1,4 @@
+import gc
 import platform
 from dataclasses import dataclass
 from functools import partial
@@ -16,14 +17,17 @@ from fedot.core.composer.optimisers.gp_comp.operators.inheritance import Genetic
 from fedot.core.composer.optimisers.gp_comp.operators.mutation import MutationStrengthEnum
 from fedot.core.composer.optimisers.gp_comp.operators.regularization import RegularizationTypesEnum
 from fedot.core.composer.optimisers.gp_comp.param_free_gp_optimiser import GPChainParameterFreeOptimiser
-from fedot.core.data.data import InputData, train_test_data_setup
+from fedot.core.data.data import InputData
+from fedot.core.data.data_split import train_test_data_setup, train_test_multi_modal_data_setup
+from fedot.core.data.multi_modal import MultiModalData
 from fedot.core.log import Log, default_log
+from fedot.core.operations.cross_validation import cross_validation
 from fedot.core.repository.operation_types_repository import OperationTypesRepository, get_operations_for_task
 from fedot.core.repository.quality_metrics_repository import ClassificationMetricsEnum, MetricsRepository, \
     RegressionMetricsEnum, MetricsEnum
 from fedot.core.repository.tasks import Task, TaskTypesEnum
 
-sample_split_ration_for_tasks = {
+sample_split_ratio_for_tasks = {
     TaskTypesEnum.classification: 0.8,
     TaskTypesEnum.regression: 0.8,
     TaskTypesEnum.ts_forecasting: 0.5
@@ -98,15 +102,13 @@ class GPComposer(Composer):
         else:
             self.log = logger
 
-    def compose_chain(self, data: InputData, is_visualise: bool = False, is_tune: bool = False,
+    def compose_chain(self, data: Union[InputData, MultiModalData], is_visualise: bool = False, is_tune: bool = False,
                       on_next_iteration_callback: Optional[Callable] = None) -> Union[Chain, List[Chain]]:
         """ Function for optimal chain structure searching
-
         :param data: InputData for chain composing
         :param is_visualise: is it needed to visualise
         :param is_tune: is it needed to tune chain after composing TODO integrate new tuner
         :param on_next_iteration_callback: TODO add description
-
         :return best_chain: obtained result after composing: one chain for single-objective optimization;
             For the multi-objective case, the list of the chain is returned.
             In the list, the chains are ordered by the descending of primary metric (the first is the best)
@@ -118,15 +120,23 @@ class GPComposer(Composer):
         if not self.optimiser:
             raise AttributeError(f'Optimiser for chain composition is not defined')
 
-        train_data, test_data = train_test_data_setup(data,
-                                                      sample_split_ration_for_tasks[data.task.task_type])
+        if self.composer_requirements.cv_folds is not None:
+            if isinstance(data, MultiModalData):
+                raise NotImplementedError('Cross-validation is not supported for multi-modal data')
+            self.log.info("KFolds cross validation for chain composing was applied.")
+            metric_function_for_nodes = partial(cross_validation, data,
+                                                self.composer_requirements.cv_folds, self.metrics)
+        else:
+            self.log.info("Hold out validation for chain composing was applied.")
+            split_ratio = sample_split_ratio_for_tasks[data.task.task_type]
+            train_data, test_data = train_test_setup_for_dataset(data, split_ratio)
+            metric_function_for_nodes = partial(self.composer_metric, self.metrics, train_data, test_data)
+
         if self.cache_path is None:
             self.cache.clear()
         else:
             self.cache = OperationsCache(self.cache_path, clear_exiting=not self.use_existing_cache)
 
-        metric_function_for_nodes = partial(self.composer_metric, self.metrics, train_data, test_data)
-
         best_chain = self.optimiser.optimise(metric_function_for_nodes,
                                              on_next_iteration_callback=on_next_iteration_callback)
 
@@ -136,8 +146,10 @@ class GPComposer(Composer):
             self.tune_chain(best_chain, data, self.composer_requirements.max_lead_time)
         return best_chain
 
-    def composer_metric(self, metrics, train_data: InputData,
-                        test_data: InputData, chain: Chain) -> Optional[Tuple[Any]]:
+    def composer_metric(self, metrics,
+                        train_data: Union[InputData, MultiModalData],
+                        test_data: Union[InputData, MultiModalData],
+                        chain: Chain) -> Optional[Tuple[Any]]:
         try:
             validate(chain)
             chain.log = self.log
@@ -149,10 +161,14 @@ class GPComposer(Composer):
                 # TODO improve cache
                 chain.fit_from_cache(self.cache)
 
-            if not chain.is_fitted():
+            if not chain.is_fitted:
                 self.log.debug(f'Chain {chain.root_node.descriptive_id} fit started')
-                chain.fit(input_data=train_data, time_constraint=self.composer_requirements.max_chain_fit_time)
-                self.cache.save_chain(chain)
+                chain.fit(input_data=train_data,
+                          time_constraint=self.composer_requirements.max_chain_fit_time)
+                try:
+                    self.cache.save_chain(chain)
+                except Exception as ex:
+                    self.log.info(f'Cache can not be saved: {ex}. Continue.')
 
             evaluated_metrics = ()
             for metric in metrics:
@@ -164,6 +180,9 @@ class GPComposer(Composer):
 
             self.log.debug(f'Chain {chain.root_node.descriptive_id} with metrics: {list(evaluated_metrics)}')
 
+            # enforce memory cleaning
+            chain.unfit()
+            gc.collect()
         except Exception as ex:
             self.log.info(f'Chain assessment warning: {ex}. Continue.')
             evaluated_metrics = None
@@ -269,3 +288,25 @@ class GPComposerBuilder:
         self._composer.optimiser = optimiser
 
         return self._composer
+
+
+def train_test_setup_for_dataset(dataset: Union[InputData, MultiModalData], split_ratio=0.8,
+                                 shuffle_flag=False) -> Tuple[Union[InputData, MultiModalData],
+                                                              Union[InputData, MultiModalData]]:
+    """ Function for train and test split
+
+    :param dataset: dataset for train and test splitting
+    :param split_ratio: threshold for partitioning
+    :param shuffle_flag: is data needed to be shuffled or not
+
+    :return train_data: data for train
+    :return test_data: data for validation
+    """
+    if isinstance(dataset, InputData):
+        train_data, test_data = train_test_data_setup(dataset, split_ratio, shuffle_flag)
+    elif isinstance(dataset, MultiModalData):
+        train_data, test_data = train_test_multi_modal_data_setup(dataset, split_ratio, shuffle_flag)
+    else:
+        raise ValueError(f'Dataset {type(dataset)} is not supported')
+
+    return train_data, test_data
