@@ -7,8 +7,9 @@ import numpy as np
 
 from fedot.core.composer.composing_history import ComposingHistory
 from fedot.core.composer.constraint import constraint_function
-from fedot.core.composer.optimisers.gp_comp.gp_operators import calculate_objective, duplicates_filtration, \
-    evaluate_individuals, num_of_parents_in_crossover, random_chain
+from fedot.core.composer.optimisers.gp_comp.gp_operators import calculate_objective, clean_operators_history, \
+    duplicates_filtration, evaluate_individuals, num_of_parents_in_crossover, random_chain
+from fedot.core.composer.optimisers.gp_comp.individual import Individual
 from fedot.core.composer.optimisers.gp_comp.operators.crossover import CrossoverTypesEnum, crossover
 from fedot.core.composer.optimisers.gp_comp.operators.inheritance import GeneticSchemeTypesEnum, inheritance
 from fedot.core.composer.optimisers.gp_comp.operators.mutation import MutationTypesEnum, mutation
@@ -116,7 +117,7 @@ class GPChainOptimiser:
         self.chain_generation_function = partial(random_chain, chain_generation_params=self.chain_generation_params,
                                                  requirements=self.requirements, max_depth=generation_depth)
 
-        necessary_attrs = ['add_node', 'root_node', 'replace_node_with_parents', 'update_node', 'node_childs']
+        necessary_attrs = ['add_node', 'root_node', 'update_node']
         if not all([hasattr(self.chain_class, attr) for attr in necessary_attrs]):
             ex = f'Object chain_class has no required attributes for gp_optimizer'
             self.log.error(ex)
@@ -125,10 +126,13 @@ class GPChainOptimiser:
         if not self.requirements.pop_size:
             self.requirements.pop_size = 10
 
-        if initial_chain and type(initial_chain) != list:
-            self.population = [deepcopy(initial_chain) for _ in range(self.requirements.pop_size)]
-        else:
-            self.population = initial_chain
+        self.population = None
+        if initial_chain:
+            if type(initial_chain) != list:
+                self.population = \
+                    [Individual(chain=deepcopy(initial_chain)) for _ in range(self.requirements.pop_size)]
+            else:
+                self.population = [Individual(chain=c) for c in initial_chain]
 
         self.history = ComposingHistory(metrics)
 
@@ -143,7 +147,6 @@ class GPChainOptimiser:
         num_of_new_individuals = self.offspring_size(offspring_rate)
 
         with CompositionTimer(log=self.log, max_lead_time=self.requirements.max_lead_time) as t:
-
             if self.requirements.allow_single_operations:
                 self.best_single_operation, self.requirements.primary = \
                     self._best_single_operations(objective_function, timer=t)
@@ -210,11 +213,13 @@ class GPChainOptimiser:
 
                 self.generation_num += 1
 
+                clean_operators_history(self.population)
             best = self.result_individual()
             self.log.info('Result:')
             self.log_info_about_best()
 
-        return best
+        output = [ind.chain for ind in best] if isinstance(best, list) else best.chain
+        return output
 
     @property
     def best_individual(self) -> Any:
@@ -278,9 +283,9 @@ class GPChainOptimiser:
         simpler_equivalents = {}
         for i in sort_inds:
             is_fitness_equals_to_best = is_equal_fitness(best_ind.fitness, individuals[i].fitness)
-            has_less_num_of_operations_than_best = len(individuals[i].nodes) < len(best_ind.nodes)
+            has_less_num_of_operations_than_best = individuals[i].chain.length < best_ind.chain.length
             if is_fitness_equals_to_best and has_less_num_of_operations_than_best:
-                simpler_equivalents[i] = len(individuals[i].nodes)
+                simpler_equivalents[i] = len(individuals[i].chain.nodes)
         return simpler_equivalents
 
     def reproduce(self, selected_individual_first, selected_individual_second=None) -> Tuple[Any]:
@@ -295,28 +300,28 @@ class GPChainOptimiser:
 
         new_inds = tuple([mutation(types=self.parameters.mutation_types,
                                    chain_generation_params=self.chain_generation_params,
-                                   chain=new_ind, requirements=self.requirements,
+                                   ind=new_ind, requirements=self.requirements,
                                    max_depth=self.max_depth, log=self.log) for new_ind in new_inds])
         for ind in new_inds:
             ind.fitness = None
         return new_inds
 
     def _make_population(self, pop_size: int) -> List[Any]:
-        operation_chains = []
+        pop = []
         iter_number = 0
-        while len(operation_chains) < pop_size:
+        while len(pop) < pop_size:
             iter_number += 1
             chain = self.chain_generation_function()
             if constraint_function(chain):
-                operation_chains.append(chain)
+                pop.append(Individual(chain))
 
             if iter_number > MAX_NUM_OF_GENERATED_INDS:
                 self.log.debug(
-                    f'More than {MAX_NUM_OF_GENERATED_INDS} generated In population making function. '
+                    f'More than {MAX_NUM_OF_GENERATED_INDS} generated in population making function. '
                     f'Process is stopped')
                 break
 
-        return operation_chains
+        return pop
 
     def _best_single_operations(self, objective_function: Callable, num_best: int = 7, timer=None):
         is_process_skipped = False
@@ -330,9 +335,8 @@ class GPChainOptimiser:
                 single_operations_inds.append(single_operations_ind)
 
             if single_operations_inds:
-                if timer is not None:
-                    if timer.is_time_limit_reached():
-                        break
+                if timer is not None and timer.is_time_limit_reached():
+                    break
 
         best_inds = sorted(single_operations_inds, key=lambda ind: ind.fitness)
         if is_process_skipped:
@@ -356,10 +360,13 @@ class GPChainOptimiser:
         return np.isclose(first_fitness, second_fitness, atol=atol, rtol=rtol)
 
     def default_on_next_iteration_callback(self, individuals, archive):
-        self.history.add_to_history(individuals)
-        archive = deepcopy(archive)
-        if archive is not None:
-            self.history.add_to_archive_history(archive.items)
+        try:
+            self.history.add_to_history(individuals)
+            archive = deepcopy(archive)
+            if archive is not None:
+                self.history.add_to_archive_history(archive.items)
+        except Exception as ex:
+            self.log.warn(f'Callback was not successful because of {ex}')
 
     def result_individual(self) -> Union[Any, List[Any]]:
         if not self.parameters.multi_objective:
